@@ -226,9 +226,9 @@ def _ib_mac_to_rmac_mapping(ports):
 
 
 def _get_blacklist(ironic):
-    ports = [port.address for port in
+    ports = [port for port in
              ir_utils.call_with_retries(ironic.port.list, limit=0,
                                         fields=['address', 'extra'])
              if port.address not in node_cache.active_macs()]
     _ib_mac_to_rmac_mapping(ports)
-    return ports
+    return [port.address for port in ports]
