@@ -23,6 +23,7 @@ from oslo_log import log
 from oslo_utils import reflection
 
 from ironic_inspector.common import ironic as ir_utils
+from ironic_inspector.common import rpc
 from ironic_inspector import db
 from ironic_inspector import main as app
 from ironic_inspector import node_cache
@@ -151,6 +152,8 @@ class WSGIService(object):
 
         LOG.debug('Shutting down')
 
+        self.rpc_server.stop()
+
         if self._periodics_worker is not None:
             try:
                 self._periodics_worker.stop()
@@ -185,6 +188,9 @@ class WSGIService(object):
 
         self._init_host()
 
+        self.rpc_server = rpc.get_server()
+        self.rpc_server.start()
+
         try:
             self.app.run(**app_kwargs)
         except Exception as e:
@@ -210,10 +216,14 @@ def periodic_clean_up():  # pragma: no cover
     try:
         if node_cache.clean_up():
             pxe_filter.driver().sync(ir_utils.get_client())
-        sync_with_ironic()
     except Exception:
         LOG.exception('Periodic clean up of node cache failed')
 
+    try:
+        sync_with_ironic()
+    except Exception:
+        LOG.exception('Periodic sync of node list with ironic failed')
+
 
 def sync_with_ironic():
     ironic = ir_utils.get_client()
